import { __awaiter, __decorate } from "tslib";
/**
 * See https://fdc3.finos.org/docs/fdc3-intro, and https://github.com/finos/FDC3/tree/master/src/api
 */
import { addIntentListener, fdc3Ready, findIntent, findIntentsByContext, getCurrentChannel, getOrCreateChannel, getInfo, joinChannel, raiseIntent, raiseIntentForContext, versionIsAtLeast, } from '@finos/fdc3';
import { observable } from '@microsoft/fast-element';
import { DI } from '@microsoft/fast-foundation';
import { stripOutBigInt } from './util/fdc3-util';
import { logger } from './utils';
/**
 * The FDC3 implementation.
 * @internal
 */
export class DefaultFDC3 {
    constructor() {
        this.isReady = false;
        this.connect();
    }
    connect() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                this.isReady = false;
                yield fdc3Ready();
                logger.debug('fdc3 connection success');
            }
            catch (err) {
                logger.error('fdc3 connection error', err);
                throw err;
            }
        });
    }
    addIntentListeners(listeners) {
        listeners.forEach((handler, intent) => {
            const listener = addIntentListener(intent, handler);
            logger.debug(`fdc3 addIntentListener for '${intent}', ${listener}`);
        });
    }
    findIntent(intent, context) {
        logger.debug(`fdc3 findIntent '${intent}' '${context}'`);
        return findIntent(intent, context);
    }
    findIntentsByContext(context) {
        logger.debug(`fdc3 findIntentsByContext '${context}'`);
        return findIntentsByContext(context);
    }
    raiseIntent(context, intent) {
        if (getInfo && versionIsAtLeast(getInfo(), '1.2')) {
            logger.debug(`fdc3 raiseIntentForContext '${context}'`);
            return raiseIntentForContext(context);
        }
        if (intent) {
            logger.debug(`fdc3 raiseIntent '${intent}' '${context}'`);
            return raiseIntent(intent, context);
        }
        logger.error(`fdc3 unable to raiseIntent using context '${context}' and intent '${intent}'.`);
    }
    joinChannel(channelId) {
        logger.debug(`fdc3 joinChannel '${channelId}'`);
        return joinChannel(channelId);
    }
    getOrCreateChannel(channelId) {
        logger.debug(`fdc3 getOrCreateChannel '${channelId}'`);
        return getOrCreateChannel(channelId);
    }
    broadcastOnChannel(channelName, type, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            const channel = yield getOrCreateChannel(channelName);
            payload = stripOutBigInt(payload);
            const m = {
                type,
                id: payload,
            };
            channel.broadcast(m);
        });
    }
    broadcastOnChannelEventHandler(channelName, type) {
        return __awaiter(this, void 0, void 0, function* () {
            return (e) => __awaiter(this, void 0, void 0, function* () {
                var _a;
                // check for ag-grid-specific events, fall back to standard events
                const payload = ((_a = e.data) === null || _a === void 0 ? void 0 : _a.payload) || e.detail;
                yield this.broadcastOnChannel(channelName, type, payload);
            });
        });
    }
    addChannelListener(channelName, channelType, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const channel = yield getOrCreateChannel(channelName);
            channel.addContextListener(channelType, callback);
            return channel;
        });
    }
    getCurrentChannel() {
        return __awaiter(this, void 0, void 0, function* () {
            return getCurrentChannel();
        });
    }
}
__decorate([
    observable
], DefaultFDC3.prototype, "isReady", void 0);
/**
 * The DI token for the FDC3 interface.
 * @internal
 */
export const FDC3 = DI.createInterface((x) => x.singleton(DefaultFDC3));
