import { AppIntent } from '@finos/fdc3';
import { Channel } from '@finos/fdc3';
import { Context } from '@finos/fdc3';
import { ContextHandler } from '@finos/fdc3';
import { FASTElement } from '@genesislcap/web-core';
import { FoundationElementRegistry } from '@microsoft/fast-foundation';
import { IntentResolution } from '@finos/fdc3';
import { Intents } from '@finos/fdc3';
import { InterfaceSymbol } from '@microsoft/fast-foundation';
import { IOConnectDesktop } from '@interopio/desktop';
import { NotificationDataRow } from '@genesislcap/foundation-notifications';
import { NotificationListener } from '@genesislcap/foundation-ui';
import { OverrideFoundationElementDefinition } from '@microsoft/fast-foundation';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * fdc3-listener listen channel config
 * @alpha
 */
export declare interface ChannelConfig {
    channelName: string;
    channelType: string;
    callback: (any: any) => void;
}

/**
 * The FDC3 implementation.
 * @internal
 */
export declare class DefaultFDC3 implements FDC3 {
    isReady: boolean;
    constructor();
    private connect;
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    raiseIntent(context: FDC3Context, intent?: FDC3Intents): Promise<FDC3IntentResolution>;
    joinChannel(channelId: string): Promise<void>;
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    broadcastOnChannel(channelName: string, type: string, payload: any): Promise<void>;
    broadcastOnChannelEventHandler(channelName: string, type: string): Promise<(e: any) => Promise<void>>;
    addChannelListener(channelName: string, channelType: string, callback: (any: any) => void): Promise<Channel>;
    getCurrentChannel(): Promise<Channel>;
}

/**
 * The FDC3 API interface.
 * @public
 */
export declare interface FDC3 {
    /**
     * Whether the FDC3 API is ready.
     * @public
     */
    isReady: boolean;
    /**
     * Adds intent listeners for the specified intents.
     * @public
     * @param listeners - The intent listeners to add.
     */
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    /**
     * Finds an app that supports the specified intent.
     * @public
     * @param intent - The intent to find an app for.
     * @param context - The context to use.
     * @returns A promise that resolves with the app and its metadata.
     */
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    /**
     * Finds all the intents supported by the specified context.
     * @public
     * @param context - The context to use.
     * @returns A promise that resolves with an array of all matching intents and their metadata.
     */
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    /**
     * Raises the specified intent with the specified context.
     * @public
     * @param context - The context to use.
     * @param intent - The intent to raise.
     * @returns A promise that resolves with the result of the intent resolution.
     */
    raiseIntent(context: FDC3Context, intent?: FDC3Intents): Promise<FDC3IntentResolution>;
    /**
     * Joins the specified channel.
     * @public
     * @param channelId - The ID of the channel to join.
     * @returns A promise that resolves when the join is successful.
     */
    joinChannel(channelId: string): Promise<void>;
    /**
     * Gets or creates the specified channel.
     * @public
     * @param  channelId - The ID of the channel to get or create.
     * @returns A promise that resolves with the channel object.
     */
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    /**
     * Broadcasts a message on a given channel with a given type
     * @param channelName - name of the channel
     * @param type - type of the channel
     * @param payload - payload sent to the channel
     */
    broadcastOnChannel(channelName: string, type: string, payload: any): Promise<void>;
    /**
     * Helper function to broadcast message on channel in response to dispatched event
     * @param channelName - name of the channel
     * @param type - type of the channel
     */
    broadcastOnChannelEventHandler(channelName: string, type: string): Promise<(e: any) => Promise<void>>;
    /**
     * Helper function to add a context listener on a channel with a handler for channel messages
     * @param channelName - name of the channel
     * @param channelType - type of the channel
     * @param callback - handler to for the channel context listener
     * */
    addChannelListener(channelName: string, channelType: string, callback: (any: any) => void): Promise<Channel>;
    /**
     * Helper function to get the current channel of the application
     * */
    getCurrentChannel(): Promise<Channel>;
}

/**
 * The DI token for the FDC3 interface.
 * @internal
 */
export declare const FDC3: InterfaceSymbol<FDC3>;

/**
 * @public
 */
export declare interface FDC3AppIntent extends AppIntent {
}

/**
 * @public
 */
export declare interface FDC3Channel extends Channel {
}

/**
 * fdc3-channel-event
 * @internal
 */
export declare class Fdc3ChannelEvent extends FASTElement {
    fdc3: FDC3;
    eventName: string;
    channelType: string;
    channelName: string;
    mappingFunction: (any: any) => any;
    connectedCallback(): void;
    disconnectedCallback(): void;
    private sendEventOnChannel;
}

/**
 * @public
 */
export declare interface FDC3Context extends Context {
}

/**
 * @public
 */
export declare type FDC3ContextHandler = ContextHandler;

/**
 * @public
 */
export declare interface FDC3IntentResolution extends IntentResolution {
}

/**
 * @public
 */
export declare type FDC3Intents = Intents;

/**
 * fdc3-listener
 * @alpha
 */
export declare class Fdc3Listener extends FASTElement {
    fdc3: FDC3;
    intentConfig: IntentConfig[];
    channelConfig: ChannelConfig[];
    connectedCallback(): void;
}

/**
 * fdc3-raise-intent
 * @alpha
 */
export declare class Fdc3RaiseIntent extends FASTElement {
    fdc3: FDC3;
    eventName: string;
    intentType: string;
    intentName: string;
    mappingFunction: (any: any) => any;
    connectedCallback(): void;
    disconnectedCallback(): void;
    private sendEventOnChannel;
}

/**
 * fdc3-listener listen intent config
 * @alpha
 */
export declare interface IntentConfig {
    intent: string;
    callback: (any: any) => void;
}

/**
 * The Foundation Interop Notification Listener
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-interop-notification-listener\>
 */
export declare const interopFoundationNotificationListener: (overrideDefinition?: OverrideFoundationElementDefinition<    {
baseName: string;
template: ViewTemplate<NotificationListener, any>;
shadowOptions: ShadowRootInit;
}>) => FoundationElementRegistry<    {
baseName: string;
template: ViewTemplate<NotificationListener, any>;
shadowOptions: ShadowRootInit;
}, typeof InteropNotificationsListener>;

/**
 * @tagname %%prefix%%-interop-notification-listener
 * @public
 * @remarks
 * This component extends the notification listener class and overrides the logic for showing the toast message to instead dispatch the event to the interop notifications bus.
 */
export declare class InteropNotificationsListener extends NotificationListener {
    iOConnectNotificationOptions: IOConnectDesktop.Notifications.IOConnectNotificationOptions;
    protected showNotificationToast(row: NotificationDataRow): void;
}

export { }
